# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/location/locations/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/location/locations/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Location\\Locations\\": "packages/location/locations/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Location\Locations\Providers\LocationsServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Locations'  => Location\Locations\Facades\Locations::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Location\\LocationsTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Location\Locations\Providers\LocationsServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Location\Locations\Providers\LocationsServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Location\Locations\Providers\LocationsServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/locations/{modulename}

**User**

    http://path-to-route-folder/user/locations/{modulename}

**Public**

    http://path-to-route-folder/locations


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/locations/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/locations/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/locations/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/locations/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/locations/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/locations/{modulename}/{slug}
    METHOD: GET